@@ -1,7 +1,7 @@
 package Bencher::Formatter::DeleteConstantFields;
 
-our $DATE = '2017-01-25'; # DATE
-our $VERSION = '1.034'; # VERSION
+our $DATE = '2017-02-19'; # DATE
+our $VERSION = '1.035'; # VERSION
 
 use 5.010001;
 use strict;
@@ -24,7 +24,7 @@ sub munge_result {
         last unless $td->row_count >= 2;
         my @const_cols = $td->const_col_names;
         for my $k (@const_cols) {
-            next unless $k =~ /^(item_.+|arg_.+|perl|modver|participant|dataset)$/;
+            next unless $k =~ /^(item_.+|arg_.+|perl|modver|participant|p_.+|dataset|ds_.+)$/;
             $self->delete_fields($envres, $k);
         }
     }
@@ -45,7 +45,7 @@ Bencher::Formatter::DeleteConstantFields - Delete constant item permutation fiel
 
 =head1 VERSION
 
-This document describes version 1.034 of Bencher::Formatter::DeleteConstantFields (from Perl distribution Bencher-Backend), released on 2017-01-25.
+This document describes version 1.035 of Bencher::Formatter::DeleteConstantFields (from Perl distribution Bencher-Backend), released on 2017-02-19.
 
 =head1 DESCRIPTION
 
@@ -79,7 +79,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
